@@ -12,36 +12,15 @@ from .models import *
 @task()
 def reset_trigrams():
     files = sorted(os.listdir(settings.TRIGRAM_PATH))
-    c2 = (delete_all.si() | load_orths.si(files) | load_trigrams.si(files))
+    c2 = (delete_all.si() | load_trigrams.si(files))
     res = c2()
     res.get()
 
 
 @task()
 def delete_all():
-    Orthography.objects.all().delete()
     Trigram.objects.all().delete()
 
-@task()
-def load_orths(files):
-    orths = set([])
-    for f in files:
-        print f
-        orths.update(load_ortho_file(f))
-    orths = [Orthography(spelling = x) for x in orths]
-    Orthography.objects.bulk_create(orths)
-
-
-@task()
-def load_ortho_file(f):
-    print f
-    orths = set([])
-    with open(os.path.join(settings.TRIGRAM_PATH,f),'r') as file_handle:
-        for line in file_handle:
-            l = line.strip().split("\t")
-            orths.update(l[0].split(" "))
-    return orths
-
 
 @task()
 def load_trigrams(files):
@@ -57,7 +36,7 @@ def load_trigram_file(f):
             l = line.strip().split("\t")
             words = []
             for w in l[0].split(" "):
-                words.append(Orthography.objects.get(spelling=w))
+                words.append(Orthography.objects.filter(spelling=w)[0])
             trgs.append(Trigram(word=words[-1],word_i_minus_one=words[1],word_i_minus_two=words[0],count=int(l[1])))
             if len(trgs) > 100000:
                 Trigram.objects.bulk_create(trgs)
